@@ -1,4 +1,4 @@
-#' @title Query basic information (including name, symbol, position and description, etc. ) of genes.
+#' @title Query basic information for genes, including name, symbol, position and description
 #' @param genes A charater vector or a string of gene symbol, gencode id (versioned or unversioned), or a charater string of gene type.
 #' \itemize{
 #'   \item \strong{gene symbol (Default)}.
@@ -259,7 +259,7 @@ xQTLquery_gene <- function(genes="", geneType="auto", recordPerChunk=150){
   }
 }
 
-#' @title Query sample's details with tissue name
+#' @title Query details of samples by tissue name
 #' @param tissueSiteDetail (character) details of tissues in GTEx can be listed using `tissueSiteDetailGTExv8` or `tissueSiteDetailGTExv7`
 #' @param dataType A character string. Options: "RNASEQ" (default), "WGS", "WES", "OMNI".
 #' @param recordPerChunk (integer) number of records fetched per request (default: 200).
@@ -427,7 +427,7 @@ xQTLquery_sampleByTissue <- function( tissueSiteDetail="Liver", dataType="RNASEQ
 
 
 
-#' @title Query sample's details with samples' IDs.
+#' @title Query details of samples with GTEx IDs
 #' @param sampleIds A character vector or a string of sample ID.
 #' @param recordPerChunk (integer) number of records fetched per request (default: 200).
 #' @param pathologyNotesCategories Default: pathologyNotes info is ignored.
@@ -523,7 +523,7 @@ xQTLquery_sampleBySampleId <- function(sampleIds,recordPerChunk=150, pathologyNo
 
 
 
-#' @title Fetch details of all genes supported in GTEx.
+#' @title Query all genes supported in GTEx
 #' @param gencodeVersion (character) options: "v26"(default, matched with gtex_v8) or "v19"
 #' @param recordPerChunk (integer) number of records fetched per request (default: 2000).
 #' @import utils
@@ -603,7 +603,7 @@ xQTLquery_geneAll <- function(gencodeVersion="v26", recordPerChunk=2000){
 }
 
 
-#' @title Query variant in GTEx with variant ID or dbSNP ID
+#' @title Query variant with variant ID or dbSNP ID
 #' @param variantName (character) name of variant, dbsnp ID and variant id is supported, eg. "rs138420351" and "chr17_7796745_C_T_b38".
 #' @param variantType (character) options: "auto", "snpId" or "variantId". Default: "auto".
 #' @import data.table
@@ -696,7 +696,7 @@ xQTLquery_varId <- function(variantName="", variantType="auto"){
   return(outInfo)
 }
 
-#' @title Query varints in GTEx using genome position.
+#' @title Query variants using genome position.
 #' @param chrom (character) name of chromesome, including chr1-chr22, chrX, chrY.
 #' @param pos An integer array.
 #' @param recordPerChunk (integer) number of records fetched per request (default: 200).
@@ -796,7 +796,7 @@ xQTLquery_varPos <- function(chrom="", pos=numeric(0), recordPerChunk=200){
 }
 
 
-#' @title Fetch all details of a specified tissue or all tissues
+#' @title Query details for a specified tissue
 #' @description
 #'  Information includes tissue IDs, number of RNA-Seq samples, number of RNA-Seq samples with genotype, number of expressed genes, number of eGenes. Also includes tissueSiteDetail ID, name, abbreviation, uberon ID, and standard tissue colors. TissueSiteDetails are grouped by TissueSites. By default, this service reports from the latest GTEx release.
 #' @param tissueName Tissue name, tissue ID or tissue site name. Default return all tissues' information. Can be choonse from `tissueSiteDetailGTExv8` or `tissueSiteDetailGTExv7`
@@ -997,6 +997,7 @@ apiEbi_ping <- function(){
 #' @param method Can be chosen from "download", "curl", "fromJSON".
 #' @param downloadMethod The same methods from utils::download.file function.
 #' @param isJson Fetched content is a json file or not. Defaulst: TRUE.
+#' @param retryTimes retry times. Default:4
 #' @import utils
 #' @import jsonlite
 #' @import stringr
@@ -1004,7 +1005,7 @@ apiEbi_ping <- function(){
 #' @importFrom curl curl_fetch_memory
 #' @keywords internal
 #' @return A json object.
-fetchContent <- function(url1, method="curl", downloadMethod="auto", isJson=TRUE){
+fetchContent <- function(url1, method="curl", downloadMethod="auto", isJson=TRUE, retryTimes=4){
   # if( method == "GetWithHeader"){
   #   mycookie <- ''
   #   myheaders <- c('accept' ='ext/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
@@ -1026,18 +1027,18 @@ fetchContent <- function(url1, method="curl", downloadMethod="auto", isJson=TRUE
   if(method == "fromJSON"){
     if(isJson){
 
-      for (downloadTime in 1:4){
+      for (downloadTime in 1:retryTimes){
         # because of the limitation of the length of the url (<2084), so I rebulit the function.
         df <- try( url1GetText2Json <- jsonlite::fromJSON(url1, simplifyDataFrame=TRUE, flatten = TRUE), silent=TRUE)
         # methods::is(df, 'try-error')
         if( !(inherits(df, "try-error")) && exists("url1GetText2Json") ){
           break()
-        }else if( (inherits(df, "try-error")) && !exists("url1GetText2Json") && downloadTime>3 ){
+        }else if( (inherits(df, "try-error")) && !exists("url1GetText2Json") && downloadTime>(retryTimes-1) ){
           message("No data fetched...")
           return(NULL)
         }
-        if(downloadTime>1){message("=> Download failed and try again...",downloadTime-1,"/",3)}
-        if(downloadTime>3){message("=> Your connection is unstable.")}
+        if(downloadTime>1){message("=> Download failed and try again...",downloadTime-1,"/",(retryTimes-1))}
+        if(downloadTime>(retryTimes-1)){message("=> Your connection is unstable.")}
       }
 
       # url1GetText2Json <- jsonlite::fromJSON(url1, simplifyDataFrame=TRUE, flatten = TRUE)
@@ -1067,9 +1068,9 @@ fetchContent <- function(url1, method="curl", downloadMethod="auto", isJson=TRUE
     tmpFile <- tempfile(pattern = "file")
     if( file.exists(tmpFile) ){ file.remove(tmpFile) }
     # Retry for-loop R loop if error
-    for (downloadTime in 1:4){
-      if(downloadTime>1){message("=> Download failed and try again...",downloadTime-1,"/",3)}
-      if(downloadTime>3){message("=> Your connection is unstable, please download  in brower directly using following url: ")
+    for (downloadTime in 1:retryTimes){
+      if(downloadTime>1){message("=> Download failed and try again...",downloadTime-1,"/",(retryTimes-1))}
+      if(downloadTime>(retryTimes-1)){message("=> Your connection is unstable, please download  in brower directly using following url: ")
         message(url1)}
       df <- try(suppressWarnings(utils::download.file(url = url1, destfile=tmpFile, method=downloadMethod,quiet = TRUE )), silent=TRUE)
       if(!(inherits(df, "try-error"))) break
@@ -1126,7 +1127,7 @@ fetchContent <- function(url1, method="curl", downloadMethod="auto", isJson=TRUE
 }
 
 
-#' @title Fetch records from
+#' @title Fetch variant from Ebi
 #'
 #' @param url1 A url string.
 #' @param method Can be chosen from "download", "curl".
@@ -1359,7 +1360,7 @@ EBIquery_allTerm <- function( term="genes", termSize=2000){
 
 
 
-#' @title Extract gene infor of specified genome from gencodeGeneInfoAllGranges
+#' @title Extract gene details from gencodeGeneInfoAllGranges object
 #'
 #' @param gencodeGeneInfoAllGranges from internal data
 #' @param genomeVersion "v26" (default) or "v19"
@@ -1392,7 +1393,7 @@ extractGeneInfo <- function(gencodeGeneInfoAllGranges, genomeVersion="v26"){
 
 
 
-#' @title Retrive SNP pairwise LD from LDlink database
+#' @title Retrieve SNP pairwise LD from LDlink database
 #'
 #' @param targetSnp target SNP, support dbSNP IP.
 #' @param population Supported population is consistent with the LDlink, which can be listed using function LDlinkR::list_pop()
@@ -1404,9 +1405,6 @@ extractGeneInfo <- function(gencodeGeneInfoAllGranges, genomeVersion="v26"){
 #'
 #' @export
 #' @return A data.table object.
-#'
-#' @examples
-#' # snpLD <- retrieveLD_LDproxy("rs3", windowSize=5000)
 retrieveLD_LDproxy <- function(targetSnp="", population="EUR" , windowSize=50000, method="download", genomeVersion="grch38", max_count=3, token="9246d2db7917"){
   # targetSnp="rs3"
   # population="EUR"
@@ -1446,7 +1444,7 @@ retrieveLD_LDproxy <- function(targetSnp="", population="EUR" , windowSize=50000
 
 
 
-#' @title query multi-tissue eQTL metasoft results
+#' @title Query multi-tissue eQTL metasoft results
 #' @description
 #'  can be quried with a gene/variant-gene pair.
 #' @param variantName (character) name of variant, dbsnp ID and variant id is supported, eg. "rs138420351" and "chr17_7796745_C_T_b38".
@@ -1636,7 +1634,7 @@ xQTLquery_eqtl <- function(variantName="", gene="", variantType="auto", geneType
 }
 
 
-#' @title Download significant eQTL associations of a specified tissue or across all tissues.
+#' @title Query significant eQTL associations for a specified tissue or multiple tissues.
 #' @param variantName (character) name of variant, dbsnp ID and variant id is supported, eg. "rs138420351" and "chr17_7796745_C_T_b38".
 #' @param genes (character string or a character vector) gene symbols or gencode ids (versioned or unversioned are both supported).
 #' @param variantType (character) options: "auto", "snpId" or "variantId". Default: "auto".
@@ -1795,7 +1793,7 @@ xQTLquery_eqtlSig <- function(variantName="", genes="", variantType="auto", gene
 
 
 
-#' @title Download significant sQTL associations of a tissue or across all tissues
+#' @title Query significant sQTL associations for a tissue or multple tissues
 #' @description
 #'  Only GTEx v8 is supported.
 #' @param variantName (character) name of variant, dbsnp ID and variant id is supported, eg. "rs138420351" and "chr17_7796745_C_T_b38".
@@ -1946,7 +1944,7 @@ xQTLquery_sqtlSig <- function(variantName="", genes="", variantType="auto", gene
 }
 
 
-#' @title query sc-eQTL study details
+#' @title Query metadata of sc-eQTLs
 #'
 #' @return A data.table object
 #' @export
@@ -1957,7 +1955,7 @@ xQTLquery_scInfo <- function(){
 }
 
 
-#' @title query significant sc-eQTLs
+#' @title Query significant sc-eQTLs for a specified gene
 #'
 #' @param gene (character) gene symbol or gencode id (versioned or unversioned are both supported).
 #' @param geneType (character) options: "auto","geneSymbol" or "gencodeId". Default: "geneSymbol".
@@ -1968,14 +1966,9 @@ xQTLquery_scInfo <- function(){
 #'
 #' @return A data.table object
 #' @export
-#'
-#' @examples
-#' \donttest{
-#'  xQTLquery_sc(gene="TP53", cell_type = "B cell",
-#'               qtl_type="Cell-type eQTL", study_name = "Resztak2022biorxiv")
-#' }
 xQTLquery_sc <- function(gene="BIN3",geneType="geneSymbol", cell_type="Astrocytes", cell_state="", qtl_type="Cell-type eQTL", study_name="Bryois2022NN"){
   tmp <- tissueSiteDetail <- genes <- NULL
+
   study_info <- xQTLquery_scInfo()
 
   if(geneType=="gencodeId"){
